@@ -7,11 +7,11 @@ from starlite.exceptions import ImproperlyConfiguredException
 from starlite.handlers.base import BaseRouteHandler
 from starlite.utils import is_async_callable
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from starlite.types import AsyncAnyCallable
 
 
-class WebsocketRouteHandler(BaseRouteHandler):
+class WebsocketRouteHandler(BaseRouteHandler["WebsocketRouteHandler"]):
     def __call__(self, fn: "AsyncAnyCallable") -> "WebsocketRouteHandler":
         """
         Replaces a function with itself
