@@ -19,6 +19,7 @@ if TYPE_CHECKING:
     from pydantic.fields import ModelField
 
     from starlite.handlers import BaseRouteHandler
+    from starlite.provide import Provide
 
 
 def create_path_parameter_schema(
@@ -115,6 +116,71 @@ def create_parameter(
     )
 
 
+def get_recursive_handler_parameters(
+    field_name: str,
+    model_field: "ModelField",
+    dependencies: Dict[str, "Provide"],
+    route_handler: "BaseRouteHandler",
+    path_parameters: List[Dict[str, Any]],
+    generate_examples: bool,
+) -> List[Parameter]:
+    """Create and return parameters for a handler. If the provided field is not a dependency,
+    a normal parameter is created and returned as a list, otherwise
+    `create_parameter_for_handler()` is called to generate parameters for the dependency."""
+
+    if field_name not in dependencies:
+        return [
+            create_parameter(
+                model_field=model_field,
+                parameter_name=field_name,
+                path_parameters=path_parameters,
+                generate_examples=generate_examples,
+            )
+        ]
+    dependency_fields = cast(BaseModel, dependencies[field_name].signature_model).__fields__
+    return create_parameter_for_handler(route_handler, dependency_fields, path_parameters, generate_examples)
+
+
+def get_layered_parameter(
+    field_name: str,
+    signature_model_field: "ModelField",
+    layered_parameters: Dict[str, "ModelField"],
+    path_parameters: List[Dict[str, Any]],
+    generate_examples: bool,
+) -> Parameter:
+    """Create a layered parameter for a given signature model field.
+    Layer info is extracted from the provided `layered_parameters` dict
+    and set as the field's `field_info` attribute."""
+    layer_field_info = layered_parameters[field_name].field_info
+    signature_field_info = signature_model_field.field_info
+
+    field_info = layer_field_info
+    # allow users to manually override Parameter definition using Parameter
+    if signature_field_info.extra.get(EXTRA_KEY_IS_PARAMETER):
+        field_info = signature_field_info
+
+    field_info.default = (
+        signature_field_info.default
+        if signature_field_info.default not in [Undefined, Ellipsis]
+        else layer_field_info.default
+    )
+
+    model_field = copy(signature_model_field)
+    model_field.field_info = field_info
+
+    extra = field_info.extra
+    parameter_name = (
+        extra.get(ParamType.QUERY) or extra.get(ParamType.HEADER) or extra.get(ParamType.COOKIE) or field_name
+    )
+
+    return create_parameter(
+        model_field=model_field,
+        parameter_name=parameter_name,
+        path_parameters=path_parameters,
+        generate_examples=generate_examples,
+    )
+
+
 def create_parameter_for_handler(
     route_handler: "BaseRouteHandler",
     handler_fields: Dict[str, "ModelField"],
@@ -135,21 +201,16 @@ def create_parameter_for_handler(
         if extra.get("is_dependency") and field_name not in dependencies:
             # never document explicit dependencies
             continue
-        if field_name in dependencies:
-            dependency_fields = cast(BaseModel, dependencies[field_name].signature_model).__fields__
-            for parameter in create_parameter_for_handler(
-                route_handler, dependency_fields, path_parameters, generate_examples
-            ):
-                parameters.add(parameter)
-        else:
-            parameters.add(
-                create_parameter(
-                    model_field=model_field,
-                    parameter_name=field_name,
-                    path_parameters=path_parameters,
-                    generate_examples=generate_examples,
-                )
-            )
+        for parameter in get_recursive_handler_parameters(
+            field_name=field_name,
+            model_field=model_field,
+            dependencies=dependencies,
+            route_handler=route_handler,
+            path_parameters=path_parameters,
+            generate_examples=generate_examples,
+        ):
+            parameters.add(parameter)
+
     for field_name, model_field in filter(
         lambda items: items[0] not in RESERVED_KWARGS and items[0] not in handler_fields, layered_parameters.items()
     ):
@@ -161,38 +222,17 @@ def create_parameter_for_handler(
                 generate_examples=generate_examples,
             )
         )
-    for field_name, signature_model_filed in filter(
+    for field_name, signature_model_field in filter(
         lambda items: items[0] not in RESERVED_KWARGS and items[0] in layered_parameters, handler_fields.items()
     ):
-
-        layer_field_info = layered_parameters[field_name].field_info
-        signature_field_info = signature_model_filed.field_info
-
-        field_info = layer_field_info
-        # allow users to manually override Parameter definition using Parameter
-        if signature_field_info.extra.get(EXTRA_KEY_IS_PARAMETER):
-            field_info = signature_field_info
-
-        field_info.default = (
-            signature_field_info.default
-            if signature_field_info.default not in [Undefined, Ellipsis]
-            else layer_field_info.default
-        )
-
-        model_field = copy(signature_model_filed)
-        model_field.field_info = field_info
-
-        extra = field_info.extra
-        parameter_name = (
-            extra.get(ParamType.QUERY) or extra.get(ParamType.HEADER) or extra.get(ParamType.COOKIE) or field_name
-        )
-
         parameters.add(
-            create_parameter(
-                model_field=model_field,
-                parameter_name=parameter_name,
+            get_layered_parameter(
+                field_name=field_name,
+                signature_model_field=signature_model_field,
+                layered_parameters=layered_parameters,
                 path_parameters=path_parameters,
                 generate_examples=generate_examples,
             )
         )
+
     return parameters.list()
